<?php
/**
 * @package PreventXSSVulnerability\Admin
 */

class Prevent_XSS_Vulnerability_Self_Settings {

  /**
   * Call Reflected Settings Function.
   */
  function __construct() {
    $this->self_xss_settings_page();
  }

  /**
   * Self-XSS Settings Page
   *
   * @access private
   * @since 0.3.0
   *
   * @return void
   */
  private function self_xss_settings_page() {
    if ( ! current_user_can( 'administrator' ) )  {
      wp_die( __( 'You do not have sufficient permissions to access this page.', 'prevent-xss-vulnerability' ) );
    }
    if ( isset( $_POST['submit'] ) ) {
      $self_xss                    = array();
      $self_xss['warning_message'] = '';
      $self_xss['user_warning']    = 0;

      if ( isset( $_POST['warning_message'] )
        && ! empty( $_POST['warning_message'] ) ) {
        $self_xss['warning_message'] = esc_html( $_POST['warning_message'] );
      }

      if ( isset( $_POST['user_warning'] ) && 1 == $_POST['user_warning'] ) {
        $self_xss['user_warning'] = 1;
      }

      update_option(
        'prevent_xss_vulnerability_self_xss_settings',
        serialize( $self_xss )
      );
    }

    $get_self_xss = unserialize( get_option(
      'prevent_xss_vulnerability_self_xss_settings'
    ) );

    $warning_message = '';
    if ( isset( $get_self_xss['warning_message'] )
      && ! empty( $get_self_xss['warning_message'] ) ) {
      $warning_message = $get_self_xss['warning_message'];
    }

    $user_warning = '';
    if ( isset( $get_self_xss['user_warning'] )
      && 1 == $get_self_xss['user_warning'] ) {
      $user_warning = 'checked';
    }

    $plugin_url = plugins_url( '/admin', PREVENT_XSS_VULNERABILITY_FILE );
    wp_enqueue_style( 'style', $plugin_url . '/css/admin-style.min.css' );

    $html = '<div class="wrap">' .
              '<h2>' .
                __( 'Self-XSS Settings', 'prevent-xss-vulnerability' ) .
              '</h2>' .
              '<div>' .
                '<p>' .
                  __( 'Self-XSS is a social engineering attack used to gain control of victims\' web accounts. In a self-XSS attack, the victim of the attack unknowingly runs malicious code in their own web browser, thus exposing it to the attacker.', 'prevent-xss-vulnerability' ) .
                '</p>' .
              '</div>' .
              '<form enctype="multipart/form-data" action="" method="POST" id="reflected-xss">' .
                '<table class="prevent-xss reflected-xss">' .
                  '<caption>' .
                    __( 'Warn users about self-XSS attacks', 'prevent-xss-vulnerability' ) .
                  '</caption>' .
                  '<tbody>' .
                    '<tr>' .
                      '<td>' .
                        '<textarea name="warning_message" rows="5" cols="100">' .
                          $warning_message .
                        '</textarea>' .
                        '<small>' .
                          __( 'Add warning message when users open the web developer console. Leave empty to use default.', 'prevent-xss-vulnerability' ) .
                        '</small>' .
                      '</td>' .
                    '</tr>' .
                    '<tr>' .
                      '<td class="enable">' .
                        '<input type="checkbox" name="user_warning" value=1 ' . $user_warning . ' />' .
                        '<strong>' .
                          __( 'Enable User Warning', 'prevent-xss-vulnerability' ) .
                        '</strong>' .
                      '</td>' .
                    '</tr>' .
                  '</tbody>' .
                '</table>' .

                '<p class="submit">' .
                  '<input type="submit" name="submit" id="submit" class="button button-primary" value="' . __( 'Save Changes', 'prevent-xss-vulnerability' ) . '" />' .
                '</p>' .
              '</form>' .
            '</div>';
    echo $html;
  }
}
